% Bisection method to find root of function f
% in the interval [a,b] to within tol tolerance
%
%   YOUR NAME
%
% inputs:
%  f	  function handle
%  a	  left bound of interval
%  b	  right bound of interval
%  delta  desired tolerance for the root
%  eps    desired tolerance for f(root)
%  maxit  maximum number of iterations
%
% outputs:
%  x      iterate history. The best approx found for the root is x(end)
%  a,b    interval containing the root
function [x,a,b] = bisection(f,a,b,delta,eps,maxit)

% TO BE COMPLETED
